#/*******************************************
# UBL SQA Project Make file
#
#	Abstract:
#
#	This makefile is designed to run a sequence 
#	of quality control analyses on the cfiXml 
#	schemas.
#
#
#	Author: Dr. Martin J. Burns
#	$Date: 8/11/05 2:06p $
#*******************************************/
# 
#  $Header: /_project/NIST/Source/ublsqa/UBLSQA.mak 3     8/11/05 2:06p Marty $
#

#********************************************
# Target definition
#********************************************
#
.SUFFIXES : .xml .xsd 

# Uncomment to run limited set test
TEST			= 1

#uncomment to allow copy from cvs tree
#DO_CVS_COPY = 1
#********************************************
# Paths
#********************************************
#
OUTROOT				=	log
OUTDIRXSV			=	$(OUTROOT)\XSV
OUTDIRMSX			=	$(OUTROOT)\MSX
OUTDIRXER			=	$(OUTROOT)\XER
OUTDIRSQC			=	$(OUTROOT)\SQC
OUTDIRMSV			=	$(OUTROOT)\MSV


CORESCHEMAS			=	xsd/codelist
TESTSCHEMAS			=	./
DOCUMENTSCHEMAS		=	xsd/maindoc
EXAMPLES			=	./

SOURCESCHEMAS		=	./

#program directories
SQCDIR					= .\SQC
XSVDIR					= C:\Progra~1\XSV
XERDIR					= .\XERCES
MSXDIR					= .\MSValidate
MSVDIR					= .\MSV



#********************************************
# flags and arguments
#********************************************
#
SQCCLASSPATH		= $(CLASSPATH)$(SQCDIR);$(SQCDIR)\xml4j.jar;$(SQCDIR)\mofrt.jar;$(SQCDIR)\xschemaREC.jar;$(SQCDIR)\xmlParserAPIs.jar;$(SQCDIR)\xercesImpl.jar;
XERCLASSPATH		= $(XERDIR)/xercesImpl.jar;$(XERDIR)/xmlParserAPIs.jar;$(XERDIR)/xercesSamples.jar

#SQC_FLAGS = -cost 10 -reportAsXML $(OUTDIRSQC)/$(@B).xml
SQC_FLAGS = -cost 3 -reportAsXML $(OUTDIRSQC)/$(@B).xml
XSV_FLAGS = -i -w -e -s $(XSVDIR)\xsv.xsl -o $(OUTDIRXSV)/$(@B).xml
MSX_FLAGS = $(OUTDIRMSX)/$(@B).txt
XER_FLAGS = -Xmx512m -classpath $(XERCLASSPATH) xni.Counter -s -v 
MSV_FLAGS = -warning -strict -verbose -xerces 

#********************************************
# Directory tree construction/verification
#********************************************
#
$(OUTROOT):
	if NOT EXIST $(OUTROOT)\nul md $(OUTROOT)
	if NOT EXIST $(OUTDIRXSV)\nul md $(OUTDIRXSV)
	if NOT EXIST $(OUTDIRMSX)\nul md $(OUTDIRMSX)
	if NOT EXIST $(OUTDIRXER)\nul md $(OUTDIRXER)
	if NOT EXIST $(OUTDIRSQC)\nul md $(OUTDIRSQC)
    if NOT EXIST $(OUTDIRMSV)\nul md $(OUTDIRMSV)

#********************************************
# Get schema tree from source
#********************************************
#
!IFDEF DO_CVS_COPY 

!ENDIF

log\XSV\myUBLExtensions.xml:	myUBLExtensions.xsd
	@echo ===============================================================================
	@echo Processing $(TESTSCHEMAS)/$(@B).xsd
	@echo ===============================================================================
	$(MSXDIR)\MSValidate $(MSX_FLAGS) $(TESTSCHEMAS)/$(@B).xsd 
	$(XSVDIR)\xsv	$(XSV_FLAGS) $(TESTSCHEMAS)/$(@B).xsd  
	java -Xmx512m -classpath $(SQCCLASSPATH) com.ibm.sketch.util.SchemaQualityChecker $(SQC_FLAGS) $(TESTSCHEMAS)/$(@B).xsd
    -java -jar $(MSVDIR)/msv.jar $(MSV_FLAGS) $(TESTSCHEMAS)/$(@B).xsd > $(OUTDIRMSV)/$(@B).txt
	@echo -------------------------------------------------------------------------------

#********************************************
# Inference rules for building reports
#********************************************
#
#********************************************
#	Check the core schemas
#********************************************
{$(CORESCHEMAS)\}.xsd.{$(OUTDIRXSV)\}.xml: 
	@echo ===============================================================================
	@echo Processing $(CORESCHEMAS)/$(@B).xsd
	@echo ===============================================================================
	$(MSXDIR)\MSValidate $(MSX_FLAGS) $(CORESCHEMAS)/$(@B).xsd 
	$(XSVDIR)\xsv	$(XSV_FLAGS) $(CORESCHEMAS)/$(@B).xsd  
	java -Xmx512m -classpath $(SQCCLASSPATH) com.ibm.sketch.util.SchemaQualityChecker $(SQC_FLAGS) $(CORESCHEMAS)/$(@B).xsd
    -java -jar $(MSVDIR)/msv.jar $(MSV_FLAGS) $(CORESCHEMAS)/$(@B).xsd > $(OUTDIRMSV)/$(@B).txt
	@echo -------------------------------------------------------------------------------

#********************************************
#	Check the document schemas
#********************************************
{$(DOCUMENTSCHEMAS)\}.xsd.{$(OUTDIRXSV)\}.xml: 
	@echo ===============================================================================
	@echo Processing $(DOCUMENTSCHEMAS)/$(@B).xsd
	@echo ===============================================================================
	$(MSXDIR)\MSValidate $(MSX_FLAGS) $(DOCUMENTSCHEMAS)/$(@B).xsd 
	$(XSVDIR)\xsv	$(XSV_FLAGS) $(DOCUMENTSCHEMAS)/$(@B).xsd  
	java -Xmx512m -classpath $(SQCCLASSPATH) com.ibm.sketch.util.SchemaQualityChecker $(SQC_FLAGS) $(DOCUMENTSCHEMAS)/$(@B).xsd
    -java -jar $(MSVDIR)/msv.jar $(MSV_FLAGS) $(DOCUMENTSCHEMAS)/$(@B).xsd > $(OUTDIRMSV)/$(@B).txt
	@echo -------------------------------------------------------------------------------

#********************************************
#	Check the test schemas
#********************************************
{$(TESTSCHEMAS)\}.xsd.{$(OUTDIRXSV)\}.xml: 
	@echo ===============================================================================
	@echo Processing $(TESTSCHEMAS)/$(@B).xsd
	@echo ===============================================================================
	java -Xmx512m -classpath $(SQCCLASSPATH) com.ibm.sketch.util.SchemaQualityChecker $(SQC_FLAGS) $(TESTSCHEMAS)/$(@B).xsd
	$(MSXDIR)\MSValidate $(MSX_FLAGS) $(TESTSCHEMAS)/$(@B).xsd 
	$(XSVDIR)\xsv	$(XSV_FLAGS) $(TESTSCHEMAS)/$(@B).xsd  
    -java -jar $(MSVDIR)/msv.jar $(MSV_FLAGS) $(TESTSCHEMAS)/$(@B).xsd > $(OUTDIRMSV)/$(@B).txt
	@echo -------------------------------------------------------------------------------


#********************************************
#	Check the examples
#********************************************
{$(EXAMPLES)\}.xml.{$(OUTDIRXER)\}.txt: 
	@echo ===============================================================================
	@echo Processing $(EXAMPLES)/$(@B).xml
	@echo ===============================================================================
	java $(XER_FLAGS) $(EXAMPLES)/$(@B).xml 2> $(OUTDIRXER)/$(@B).txt
	@echo -------------------------------------------------------------------------------

#********************************************
# List of result file dependencies
#********************************************
#
#!IFDEF TEST

CORERESULTS	= \
$(OUTDIRXSV)/UBL-CodeList-CurrencyCode-1.0.xml \
$(OUTDIRSQC)/UBL-CodeList-CurrencyCode-1.0.xml

DOCUMENTRESULTS	= \
$(OUTDIRXSV)/UBL-Order-1.0.xml \
$(OUTDIRSQC)/UBL-Order-1.0.xml 

TESTRESULTS = \
$(OUTDIRXSV)/myUBLExtensions.xml\
$(OUTDIRSQC)/myUBLExtensions.xml

EXAMPLERESULTS = \
$(OUTDIRXER)/UBL-Order-1.0-Office-ExampleExtended.txt \
$(OUTDIRXER)/UBL-Order-1.0-Office-Example.txt 


#!ELSE
#
#CORERESULTS	= 
#
#DOCUMENTRESULTS	=  
#
#EXAMPLERESULTS	= 
#
#!ENDIF


#********************************************
# Dependencies
#********************************************
#
#!IFDEF DO_CVS_COPY 
#all: $(OUTROOT) $(CORESCHEMAS)\*.xsd $(DOCUMENTSCHEMAS)\*.xsd $(EXAMPLES)\*.xml $(CORERESULTS) $(DOCUMENTRESULTS) $(EXAMPLERESULTS) $(TESTRESULTS)
#!ELSE
all: $(OUTROOT) $(CORERESULTS) $(DOCUMENTRESULTS) $(EXAMPLERESULTS) $(TESTRESULTS)
#!ENDIF
